==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/WorkspaceRepositoryConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.WorkspaceRepositoryConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Git integration settings
 * @property accountName Account name
 * @property collaborationBranch Collaboration branch
 * @property hostName GitHub Enterprise host name. For example: `https://github.mydomain.com`
 * @property lastCommitId The last commit ID
 * @property projectName VSTS project name
 * @property repositoryName Repository name
 * @property rootFolder Root folder to use in the repository
 * @property tenantId The VSTS tenant ID
 * @property type Type of workspace repositoryID configuration. Example WorkspaceVSTSConfiguration, WorkspaceGitHubConfiguration
 */
public data class WorkspaceRepositoryConfigurationArgs(
    public val accountName: Output<String>? = null,
    public val collaborationBranch: Output<String>? = null,
    public val hostName: Output<String>? = null,
    public val lastCommitId: Output<String>? = null,
    public val projectName: Output<String>? = null,
    public val repositoryName: Output<String>? = null,
    public val rootFolder: Output<String>? = null,
    public val tenantId: Output<String>? = null,
    public val type: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.WorkspaceRepositoryConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.WorkspaceRepositoryConfigurationArgs =
        com.pulumi.azurenative.synapse.inputs.WorkspaceRepositoryConfigurationArgs.builder()
            .accountName(accountName?.applyValue({ args0 -> args0 }))
            .collaborationBranch(collaborationBranch?.applyValue({ args0 -> args0 }))
            .hostName(hostName?.applyValue({ args0 -> args0 }))
            .lastCommitId(lastCommitId?.applyValue({ args0 -> args0 }))
            .projectName(projectName?.applyValue({ args0 -> args0 }))
            .repositoryName(repositoryName?.applyValue({ args0 -> args0 }))
            .rootFolder(rootFolder?.applyValue({ args0 -> args0 }))
            .tenantId(tenantId?.applyValue({ args0 -> args0 }))
            .type(type?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkspaceRepositoryConfigurationArgs].
 */
@PulumiTagMarker
public class WorkspaceRepositoryConfigurationArgsBuilder internal constructor() {
    private var accountName: Output<String>? = null

    private var collaborationBranch: Output<String>? = null

    private var hostName: Output<String>? = null

    private var lastCommitId: Output<String>? = null

    private var projectName: Output<String>? = null

    private var repositoryName: Output<String>? = null

    private var rootFolder: Output<String>? = null

    private var tenantId: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value Account name
     */
    @JvmName("rromerpjujikmipn")
    public suspend fun accountName(`value`: Output<String>) {
        this.accountName = value
    }

    /**
     * @param value Collaboration branch
     */
    @JvmName("jkkhjefuxaovcqwg")
    public suspend fun collaborationBranch(`value`: Output<String>) {
        this.collaborationBranch = value
    }

    /**
     * @param value GitHub Enterprise host name. For example: `https://github.mydomain.com`
     */
    @JvmName("imypfscvajgffmna")
    public suspend fun hostName(`value`: Output<String>) {
        this.hostName = value
    }

    /**
     * @param value The last commit ID
     */
    @JvmName("uptovlcpxdjflvae")
    public suspend fun lastCommitId(`value`: Output<String>) {
        this.lastCommitId = value
    }

    /**
     * @param value VSTS project name
     */
    @JvmName("typrgfobpmfyujqt")
    public suspend fun projectName(`value`: Output<String>) {
        this.projectName = value
    }

    /**
     * @param value Repository name
     */
    @JvmName("nltqtjitilxuccbs")
    public suspend fun repositoryName(`value`: Output<String>) {
        this.repositoryName = value
    }

    /**
     * @param value Root folder to use in the repository
     */
    @JvmName("ihiajsssjoloicar")
    public suspend fun rootFolder(`value`: Output<String>) {
        this.rootFolder = value
    }

    /**
     * @param value The VSTS tenant ID
     */
    @JvmName("krqqvorscymwmuvp")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value Type of workspace repositoryID configuration. Example WorkspaceVSTSConfiguration, WorkspaceGitHubConfiguration
     */
    @JvmName("fclbtxpksonhufur")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Account name
     */
    @JvmName("jlyyjdmdrosmkevp")
    public suspend fun accountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accountName = mapped
    }

    /**
     * @param value Collaboration branch
     */
    @JvmName("adxbxoxctfrqrnia")
    public suspend fun collaborationBranch(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.collaborationBranch = mapped
    }

    /**
     * @param value GitHub Enterprise host name. For example: `https://github.mydomain.com`
     */
    @JvmName("kldmmeegimeyqyyb")
    public suspend fun hostName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hostName = mapped
    }

    /**
     * @param value The last commit ID
     */
    @JvmName("lbxxyxhsgfdmwpac")
    public suspend fun lastCommitId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastCommitId = mapped
    }

    /**
     * @param value VSTS project name
     */
    @JvmName("oglobyffghselasl")
    public suspend fun projectName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.projectName = mapped
    }

    /**
     * @param value Repository name
     */
    @JvmName("evnejcgttnpvslit")
    public suspend fun repositoryName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.repositoryName = mapped
    }

    /**
     * @param value Root folder to use in the repository
     */
    @JvmName("icpifvxawiwohlks")
    public suspend fun rootFolder(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rootFolder = mapped
    }

    /**
     * @param value The VSTS tenant ID
     */
    @JvmName("tsfpjbukucxlrhhu")
    public suspend fun tenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    /**
     * @param value Type of workspace repositoryID configuration. Example WorkspaceVSTSConfiguration, WorkspaceGitHubConfiguration
     */
    @JvmName("idigadufwpfwafsi")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): WorkspaceRepositoryConfigurationArgs = WorkspaceRepositoryConfigurationArgs(
        accountName = accountName,
        collaborationBranch = collaborationBranch,
        hostName = hostName,
        lastCommitId = lastCommitId,
        projectName = projectName,
        repositoryName = repositoryName,
        rootFolder = rootFolder,
        tenantId = tenantId,
        type = type,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/WorkspaceRepositoryConfigurationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.WorkspaceRepositoryConfigurationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Git integration settings
 * @property accountName Account name
 * @property collaborationBranch Collaboration branch
 * @property hostName GitHub Enterprise host name. For example: `https://github.mydomain.com`
 * @property lastCommitId The last commit ID
 * @property projectName VSTS project name
 * @property repositoryName Repository name
 * @property rootFolder Root folder to use in the repository
 * @property tenantId The VSTS tenant ID
 * @property type Type of workspace repositoryID configuration. Example WorkspaceVSTSConfiguration, WorkspaceGitHubConfiguration
 */
public data class WorkspaceRepositoryConfigurationArgs(
    public val accountName: Output<String>? = null,
    public val collaborationBranch: Output<String>? = null,
    public val hostName: Output<String>? = null,
    public val lastCommitId: Output<String>? = null,
    public val projectName: Output<String>? = null,
    public val repositoryName: Output<String>? = null,
    public val rootFolder: Output<String>? = null,
    public val tenantId: Output<String>? = null,
    public val type: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.WorkspaceRepositoryConfigurationArgs> {
    override fun toJava(): com.pulumi.azurenative.synapse.inputs.WorkspaceRepositoryConfigurationArgs =
        com.pulumi.azurenative.synapse.inputs.WorkspaceRepositoryConfigurationArgs.builder()
            .accountName(accountName?.applyValue({ args0 -> args0 }))
            .collaborationBranch(collaborationBranch?.applyValue({ args0 -> args0 }))
            .hostName(hostName?.applyValue({ args0 -> args0 }))
            .lastCommitId(lastCommitId?.applyValue({ args0 -> args0 }))
            .projectName(projectName?.applyValue({ args0 -> args0 }))
            .repositoryName(repositoryName?.applyValue({ args0 -> args0 }))
            .rootFolder(rootFolder?.applyValue({ args0 -> args0 }))
            .tenantId(tenantId?.applyValue({ args0 -> args0 }))
            .type(type?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkspaceRepositoryConfigurationArgs].
 */
@PulumiTagMarker
public class WorkspaceRepositoryConfigurationArgsBuilder internal constructor() {
    private var accountName: Output<String>? = null

    private var collaborationBranch: Output<String>? = null

    private var hostName: Output<String>? = null

    private var lastCommitId: Output<String>? = null

    private var projectName: Output<String>? = null

    private var repositoryName: Output<String>? = null

    private var rootFolder: Output<String>? = null

    private var tenantId: Output<String>? = null

    private var type: Output<String>? = null

    /**
     * @param value Account name
     */
    @JvmName("ihkwojlxsqravrst")
    public suspend fun accountName(`value`: Output<String>) {
        this.accountName = value
    }

    /**
     * @param value Collaboration branch
     */
    @JvmName("rxikprycmrebqkhb")
    public suspend fun collaborationBranch(`value`: Output<String>) {
        this.collaborationBranch = value
    }

    /**
     * @param value GitHub Enterprise host name. For example: `https://github.mydomain.com`
     */
    @JvmName("incbkldeexqirjlr")
    public suspend fun hostName(`value`: Output<String>) {
        this.hostName = value
    }

    /**
     * @param value The last commit ID
     */
    @JvmName("xusqdcsjdfujfrri")
    public suspend fun lastCommitId(`value`: Output<String>) {
        this.lastCommitId = value
    }

    /**
     * @param value VSTS project name
     */
    @JvmName("noalotgfujcbchhr")
    public suspend fun projectName(`value`: Output<String>) {
        this.projectName = value
    }

    /**
     * @param value Repository name
     */
    @JvmName("yilxcndyvbsaxlvi")
    public suspend fun repositoryName(`value`: Output<String>) {
        this.repositoryName = value
    }

    /**
     * @param value Root folder to use in the repository
     */
    @JvmName("nqwgxmxrjsvhbjyg")
    public suspend fun rootFolder(`value`: Output<String>) {
        this.rootFolder = value
    }

    /**
     * @param value The VSTS tenant ID
     */
    @JvmName("ltxfhdceyrxulsmr")
    public suspend fun tenantId(`value`: Output<String>) {
        this.tenantId = value
    }

    /**
     * @param value Type of workspace repositoryID configuration. Example WorkspaceVSTSConfiguration, WorkspaceGitHubConfiguration
     */
    @JvmName("nufteypdutpspwfo")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Account name
     */
    @JvmName("ecleqwfocvhldjfb")
    public suspend fun accountName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.accountName = mapped
    }

    /**
     * @param value Collaboration branch
     */
    @JvmName("fvdnxwtbaygyrsou")
    public suspend fun collaborationBranch(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.collaborationBranch = mapped
    }

    /**
     * @param value GitHub Enterprise host name. For example: `https://github.mydomain.com`
     */
    @JvmName("wcubxpjavkahiues")
    public suspend fun hostName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hostName = mapped
    }

    /**
     * @param value The last commit ID
     */
    @JvmName("pnkwhofkvmxweijg")
    public suspend fun lastCommitId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastCommitId = mapped
    }

    /**
     * @param value VSTS project name
     */
    @JvmName("qrfhkknvawrapwqp")
    public suspend fun projectName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.projectName = mapped
    }

    /**
     * @param value Repository name
     */
    @JvmName("gnrfevmplupikmlr")
    public suspend fun repositoryName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.repositoryName = mapped
    }

    /**
     * @param value Root folder to use in the repository
     */
    @JvmName("dsvnltgidsdqynns")
    public suspend fun rootFolder(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rootFolder = mapped
    }

    /**
     * @param value The VSTS tenant ID
     */
    @JvmName("bnohyuuardtghppo")
    public suspend fun tenantId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tenantId = mapped
    }

    /**
     * @param value Type of workspace repositoryID configuration. Example WorkspaceVSTSConfiguration, WorkspaceGitHubConfiguration
     */
    @JvmName("pstytwobgftcxyhw")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): WorkspaceRepositoryConfigurationArgs = WorkspaceRepositoryConfigurationArgs(
        accountName = accountName,
        collaborationBranch = collaborationBranch,
        hostName = hostName,
        lastCommitId = lastCommitId,
        projectName = projectName,
        repositoryName = repositoryName,
        rootFolder = rootFolder,
        tenantId = tenantId,
        type = type,
    )
}
